@@ -213,7 +213,9 @@ activateServiceHandler (PA* new_socket_)
 		return -1;
 	}
     SH* sh = makeServiceHandler (new_socket_);
-    sh->open ();
+    if (sh->open () < 0) {
+		sh->close ();
+	}
     return 0;
 }
 
