@@ -1,6 +1,6 @@
 // -*- c++ -*-
 //------------------------------------------------------------------------------
-// $Id: Assure.h,v 1.2 2006/07/20 02:30:53 vlg Exp $
+// $Id: Assure.h,v 1.3 2007/05/14 19:19:50 vlg Exp $
 //------------------------------------------------------------------------------
 //                           Assure.h
 //------------------------------------------------------------------------------
@@ -20,7 +20,7 @@
 
 #include "assa/Logger.h"
 
-namespace ASSA {
+// DO NOT PUT MACROS IN A NAMESPACE!
 
 /** @file Assure.h
 
@@ -115,6 +115,4 @@ namespace ASSA {
         } \
     } while (0) 
 
-} // end namespace ASSA
-
 #endif /* ASSURE_H */  
