@@ -1,10 +1,10 @@
 // -*- c++ -*-
 //------------------------------------------------------------------------------
-// $Id: CmdLineOpts.cpp,v 1.6 2006/07/20 02:30:53 vlg Exp $
+// $Id: CmdLineOpts.cpp,v 1.7 2007/05/14 19:19:50 vlg Exp $
 //------------------------------------------------------------------------------
 //                        CmdLineOpts.cpp
 //------------------------------------------------------------------------------
-//  Copyright (C) 2000,2005  Vladislav Grinchenko
+//  Copyright (C) 2000,2005,2007  Vladislav Grinchenko
 //
 //  This library is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU Library General Public
@@ -480,8 +480,12 @@ parse_args (const char* argv_[])
  * by the add_opt() call (i.e. "mac-address").
  * IniFile has same options in their normalized format (i.e. "mac_address").
  *
+ * Check to see if [options] section is present. Try all possible matches
+ * of the section name.
+ *
  * Iterate throught the set of all registered Options.  For each in the set,
  * normalize its name and lookup in IniFile's [option] section for the value.
+ *
  */
 int
 CmdLineOpts::
@@ -492,11 +496,21 @@ parse_config_file (IniFile& inifile_)
 	unsigned int count = 0;
 	string v;
 	string s;
+	string optsect_name ("options");
 	OptionSet::iterator pos = m_opts_set.begin ();
 
-	if (inifile_.find_section ("options") == inifile_.sect_end ()) {
-		m_error = "Missing [options] section in INI file!";
-		return -1;
+	if (inifile_.find_section (optsect_name) == inifile_.sect_end ()) 
+	{
+		optsect_name = "Options";
+		if (inifile_.find_section (optsect_name) == inifile_.sect_end ()) 
+		{
+			optsect_name = "OPTIONS";
+			if (inifile_.find_section (optsect_name) == inifile_.sect_end ()) 
+			{
+				m_error = "Missing [options] section in INI file!";
+				return -1;
+			}
+		}
 	}
 
 	while (pos != m_opts_set.end ()) {
@@ -504,7 +518,7 @@ parse_config_file (IniFile& inifile_)
 			s = pos->m_long_name;
 			ASSA::Utils::find_and_replace_char (s, '-', '_');
 			DL ((CMDLINEOPTS, "trying option \"%s\"\n", s.c_str ()));
-			v = inifile_.get_value ("options", s);
+			v = inifile_.get_value (optsect_name, s);
 			if (v.size ()) {
 				if (assign (&(*pos), v.c_str ())) {
 					count++;
