@@ -22,6 +22,7 @@
 #    include <unistd.h>
 #endif
 
+#include <algorithm>
 #include <string>
 #include <sstream>
 #include <iostream>
@@ -76,15 +77,25 @@ public:
 	 */
 	void sync ();
 
-	/** Reset every bit in set (OFF).
+	/** Reset every bit in the set (OFF).
 	 */
 	void reset ();
 
+
+	/** Find out the highest file descriptor in the set
+		@return highest value of file descriptor.
+	 */
+	int maxInSet ();
+
 	/** Determine how many bits are set (ON) in the set.
 	    @return Number of bits set
 	 */
 	int numSet ();
 
+	/** Determine highest handler in the set.
+		@return highest value in the set
+	*/
+
 	/** Write to debug log all bits set.
 	 */
 	void dump  ();
