@@ -26,24 +26,24 @@
 using namespace ASSA;
 
 //------------------------------------------------------------------------------
-/* 
+/*
  * Note the use of _exit () instead of exit () in the child's portion.
  * For some GUI toolkits, calling exit() causes problems.
  *
  * From Gtk+ (www.gtk.org) FAQ:
  *
- *  "When GDK opens an X display, it creates a socket file descriptor. 
- *   When you use the exit() function, you implicitly close all the 
+ *  "When GDK opens an X display, it creates a socket file descriptor.
+ *   When you use the exit() function, you implicitly close all the
  *   open file descriptors, and the underlying X library really
  *   doesn't like this. The right function to use here is _exit()."
  *
  * From UNIX exit(2) man page:
  *
- *  "The function _exit terminates the calling process "immediately". 
- *   Any open file descriptors belonging to the process are closed; 
- *   any children of the process are inherited by process 1, init, and 
+ *  "The function _exit terminates the calling process "immediately".
+ *   Any open file descriptors belonging to the process are closed;
+ *   any children of the process are inherited by process 1, init, and
  *   the process's parent is sent a SIGCHLD signal."
- * 
+ *
  * _exit() doesn't not call standard I/O cleanup routines.
  *
  * From S.A. Rago "Unix System V Network Programming", sec. 2.4, p.74
@@ -54,21 +54,21 @@ using namespace ASSA;
  *   obtain the status of its children."
  *
  * We also preserve the SIGCHLD action mask here and catch it to get
- * the child's completion status. SIGCHLD signal mask is initially set to 
- * SIG_IGN by GenServer, but can be reset later on by a third-party library 
+ * the child's completion status. SIGCHLD signal mask is initially set to
+ * SIG_IGN by GenServer, but can be reset later on by a third-party library
  * linked into the application code.
  */
 int
 Fork::
-fork_exec (const string& cmd_, 
-		   const string& args_, 
-		   Fork::wait4status_t wait_for_completion_, 
+fork_exec (const string& cmd_,
+		   const string& args_,
+		   Fork::wait4status_t wait_for_completion_,
 		   bool ignore_output_)
 {
     trace_with_mask("Fork[static]::fork_exec",FORK);
 
 	DL((FORK,"exec \"%s %s\")\n", cmd_.c_str (), args_.c_str ()));
-    if (cmd_.size () == 0) { 
+    if (cmd_.size () == 0) {
 		return -1;
     }
 
@@ -99,13 +99,13 @@ fork_exec (const string& cmd_,
 				syslog (LOG_ERR,"failed to open \"/dev/null\"");
 				_exit (-1);
 			}
-		
+
 			(void) dup2  (nullfd, 1);
 			(void) dup2  (nullfd, 2);
 			(void) close (nullfd);
 		}
 
-		execvp (cmd_.c_str (), argv);     
+		execvp (cmd_.c_str (), argv);
 
 		EL((ASSAERR,"fork_exec (\"%s\") failed\n", cmd_.c_str ()));
 		_exit (-1);
@@ -116,7 +116,7 @@ fork_exec (const string& cmd_,
     }
 
 	return f.get_exit_status ();
-	
+
 #endif // defined(WIN32)
 }
 
@@ -157,7 +157,7 @@ handle_signal (int signum_)
 
 //------------------------------------------------------------------------------
 Fork::
-Fork (Fork::state_t state_, Fork::wait4status_t catch_status_)
+Fork (Fork::state_t exit_action_, Fork::wait4status_t catch_status_)
 {
 	trace_with_mask("Fork::Fork",FORK);
 
@@ -169,11 +169,10 @@ Fork (Fork::state_t state_, Fork::wait4status_t catch_status_)
 		EL((ASSAERR,"failed to fork() - out of swap space?\n"));
 		exit (1);	                     // die right here
 	}
-	
+
 	if (m_pid) {				         // The Parent
-		if (state_ != LEAVE_ALONE) {
-			ForkList::get_instance()->
-				m_list.push_back (new fnode_t (m_pid, state_));
+		if (exit_action_ != LEAVE_ALONE) {
+			ForkList::get_instance()->m_list.push_back (new fnode_t (m_pid, exit_action_));
 		}
 		if (catch_status_ == COLLECT_STATUS) {
 			if (! m_chstath.caught ()) {
@@ -211,9 +210,9 @@ ForkList::
 		}
 		// Search for child through the list by its pid.
 		// If found, remove it from list and release memory.
-		
+
 		list<fnode_t* >::iterator j;
-		
+
 		for (j = m_list.begin(); j != m_list.end(); j++) {
 			if ((*j)->getPID() == pid) {
 				fnode_t* ep = *j;
