@@ -14,13 +14,18 @@
 #define _Handlers_h
 
 #include <sys/types.h>
-#include <sys/wait.h>
+
+#if !defined(WIN32)
+#    include <sys/wait.h>
+#endif
 
 #include "assa/EventHandler.h"
 #include "assa/Assure.h"
 
 namespace ASSA {
 
+#if !defined(WIN32)
+
 /** @file Handlers.h
 
     A collection of various most popular signal handlers.
@@ -270,6 +275,8 @@ public:
 	}
 };
 
+#endif // !defined(WIN32)
+
 } // end namespace ASSA
 
 #endif
