@@ -2,7 +2,7 @@
 //------------------------------------------------------------------------------
 //                             Logger.cpp
 //------------------------------------------------------------------------------
-// $Id: Logger.cpp,v 1.7 2006/07/20 02:30:54 vlg Exp $
+// $Id: Logger.cpp,v 1.8 2012/05/23 02:52:25 vlg Exp $
 //------------------------------------------------------------------------------
 //  Copyright (c) 2001,2005 by Vladislav Grinchenko
 //
@@ -34,7 +34,7 @@ static const int TMPBUF_SZ = 4096;
 
 // Logger's member functions
 
-int 
+int
 Logger::
 log_close (void)
 {
@@ -48,20 +48,20 @@ log_close (void)
 	return ret;
 }
 
-int 
+int
 Logger::
 log_open (u_long groups_)
 {
     if (m_impl != NULL) {
-		std::cerr << "Logger::log_open - Implementation already exist" 
+		std::cerr << "Logger::log_open - Implementation already exist"
 				  << std::endl;
 		return -1;
     }
     m_impl = new StdOutLogger;
     return m_impl->log_open (groups_);
 }
-	
-int 
+
+int
 Logger::
 log_open (const char* logfname_, u_long groups_, u_long maxsize_)
 {
@@ -72,11 +72,11 @@ log_open (const char* logfname_, u_long groups_, u_long maxsize_)
     return m_impl->log_open (logfname_, groups_, maxsize_);
 }
 
-int 
+int
 Logger::
 log_open (const std::string& logsvraddr_,
-		  const char*          logfname_, 
-		  u_long                 groups_, 
+		  const char*          logfname_,
+		  u_long                 groups_,
 		  u_long                maxsize_,
 		  Reactor*              reactor_)
 {
@@ -99,24 +99,24 @@ log_open (const std::string& logsvraddr_,
 
 		m_impl = lsp.release ();
 	}
-	int ret =  m_impl->log_open (m_app_name.c_str (), logfname_, 
+	int ret =  m_impl->log_open (m_app_name.c_str (), logfname_,
 								 groups_, maxsize_, reactor_);
 	return ret;
 }
 
 /**
-   Here is an interesting twist introduced by remote logging server: 
+   Here is an interesting twist introduced by remote logging server:
 
-   Setting errno bits puts us in an unexpected situation. 
-   Asynchronous connection establishment reliest on examening errno to see 
-   if it was set by the system call, ::connect(), to EINPROGRESS. 
-   If it was, and thus ::connect() failed, IPv4Socket::connect() would log it
-   as an error with EL() macro. When client is configured to 
+   Setting errno bits puts us in an unexpected situation.
+   Asynchronous connection establishment reliest on examening errno to see
+   if it was set by the system call, connect(), to EINPROGRESS.
+   If it was, and thus connect() failed, IPv4Socket's connect() would log it
+   as an error with EL() macro. When client is configured to
    log its messages to the server, call to EL() would result into
    the call to log_msg(), and because connection to the server
    has not yet been established, m_impl is set to 0 and errno
-   is reset to EPERM. When stack unwinds itself, Connector::connect()
-   fails because Connector::connectServiceHandler() returned 
+   is reset to EPERM. When stack unwinds itself, Connector's connect()
+   fails because Connector's connectServiceHandler() returned
    errno different from expected EINPROGRESS (it is EPERM)!
 */
 
@@ -130,12 +130,12 @@ log_open (const std::string& logsvraddr_,
  *     a negative value if an output error was encountered."
  *
  *  However, mingw relies on WIN32 implementation of the function
- *  which is inherently broken (not C99 compliant). 
+ *  which is inherently broken (not C99 compliant).
  *  From MSD reference:
  *
- *    "vsnprint returns the number of characters written if the 
+ *    "vsnprint returns the number of characters written if the
  *     the number of characters to write is less than or equal to 'cnt';
- *     if the number of characters to write is greater than 'cnt', 
+ *     if the number of characters to write is greater than 'cnt',
  *     RETURN -1 indicating that output has been truncated. The return
  *     value does not include the terminating null, if one is written.
  */
@@ -165,7 +165,7 @@ log_msg (u_long g_, const char* fmt_, ...)
 	ret = vsnprintf (bufp, len-1, fmt_, ap2);
 	va_end (ap2);
 
-	if (ret == -1 || ret >= len) 
+	if (ret == -1 || ret >= len)
 	{
 		len *= 2;
 		bufp = new char [len];
@@ -196,17 +196,17 @@ log_msg (u_long g_, const char* fmt_, ...)
 
 	expected_sz = ret + 1;
 
-//	std::cout << "Logger::log_func : expected_sz = " 
+//	std::cout << "Logger::log_func : expected_sz = "
 //			  << expected_sz << "\n" << std::flush;
 
 	/** Fromat and write message to the log
 	 */
 	va_start (ap, fmt_);
-	ret = m_impl->log_msg (static_cast<Group> (g_), 
+	ret = m_impl->log_msg (static_cast<Group> (g_),
 						   m_context.size (),
 						   m_context.size () ? m_context.top () : empty_str,
-						   expected_sz, 
-						   fmt_, 
+						   expected_sz,
+						   fmt_,
 						   ap);
 	va_end (ap);
 
@@ -216,7 +216,7 @@ log_msg (u_long g_, const char* fmt_, ...)
 	if (ret < 0) {
 		va_start (ap, fmt_);
 		vsnprintf (tmpbuf, TMPBUF_SZ -1, fmt_, ap);
-		std::cout << "m_impl->log_msg()=-1 message:\n" << tmpbuf 
+		std::cout << "m_impl->log_msg()=-1 message:\n" << tmpbuf
 				  << std::flush;
 		va_end (ap);
 	}
@@ -235,7 +235,7 @@ log_func (u_long g_, marker_t type_)
 		return -1;
 	}
 
-	return  m_impl->log_func (static_cast<Group> (g_), 
+	return  m_impl->log_func (static_cast<Group> (g_),
 							  m_context.size (),
 							  m_context.size () ? m_context.top () : empty_str,
 							  type_);
