@@ -1,6 +1,6 @@
 // -*- c++ -*-
 //------------------------------------------------------------------------------
-// $Id: Pipe.cpp,v 1.4 2005/12/17 19:53:29 vlg Exp $
+// $Id: Pipe.cpp,v 1.5 2006/07/20 02:30:54 vlg Exp $
 //------------------------------------------------------------------------------
 //                            Pipe.cpp
 //------------------------------------------------------------------------------
@@ -52,15 +52,17 @@ open (const string& cmd_, const string& type_)
 {
 	trace_with_mask("Pipe::open", PIPE);
 
+#if !defined(WIN32)       // not yet implemented
+
 	if (type_ != "r" && type_ != "w") {
-		EL((ERROR,"Wrong type \"%s\"\n", type_.c_str ()));
+		EL((ASSAERR,"Wrong type \"%s\"\n", type_.c_str ()));
 		errno = EINVAL;
 		return NULL;
 	}
 	
 	int fd [2];	
 	if (pipe (fd) < 0) {
-		EL((ERROR,"failed: pipe(2)\n"));
+		EL((ASSAERR,"failed: pipe(2)\n"));
 		return NULL;
 	}
 	Fork f (Fork::KILL_ON_EXIT, Fork::IGNORE_STATUS);
@@ -83,27 +85,32 @@ open (const string& cmd_, const string& type_)
 
 		DL((PIPE,"Executing cmd: \"%s\"\n", cmd_.c_str ()));
 		execl ("/bin/sh", "sh", "-c", cmd_.c_str (), (char* ) 0);
-		EL((ERROR,"failed: execl(2)\n"));
+		EL((ASSAERR,"failed: execl(2)\n"));
 		_exit (127);
 	}
 	/* parent */
 	if (type_ == "r") {
 		::close (fd [1]);
 		if ((m_fp = fdopen (fd [0], type_.c_str ())) == NULL) {
-			EL((ERROR,"failed: fdopen ()\n"));
+			EL((ASSAERR,"failed: fdopen ()\n"));
 			return NULL;
 		}
 	}
 	else {					// 'w'
 		::close (fd [0]);
 		if ((m_fp = fdopen (fd [1], type_.c_str ())) == NULL) {
-			EL((ERROR,"failed: fdopen ()\n"));
+			EL((ASSAERR,"failed: fdopen ()\n"));
 			return NULL;
 		}
 	}
 	m_child_pid = f.getChildPID ();
 	DL((PIPE,"m_child_pid = %d\n",m_child_pid));
 	return m_fp;
+	
+#else
+     DL((ASSAERR|PIPE,"Not implemented for win32!\n"));
+     return NULL;
+#endif
 }
 
 int 
@@ -112,11 +119,16 @@ kill ()
 {
 	trace_with_mask("Pipe::kill", PIPE);
 
+#if !defined(WIN32)
 	if (m_child_pid == 0) return -1;
 
 	int ret = ::kill (m_child_pid, SIGTERM);
 	close ();
 	return ret;
+#else
+     DL((ASSAERR|PIPE,"Not implemented for win32!\n"));
+     return -1;
+#endif
 }
 
 int 
