@@ -1,6 +1,6 @@
 // -*- c++ -*-
 //------------------------------------------------------------------------------
-// $Id: Semaphore.h,v 1.4 2006/07/20 02:30:54 vlg Exp $
+// $Id: Semaphore.h,v 1.5 2012/05/20 04:12:18 vlg Exp $
 //------------------------------------------------------------------------------
 //                               Semaphore.h
 //------------------------------------------------------------------------------
@@ -25,48 +25,49 @@
 
 namespace ASSA {
 
-/** @file Semaphore.h 
-    
-  Semaphore class provides a simpler and easier interface to System V
-  semaphore system calls. 
+/** @file Semaphore.h
 
-  The very typical situation for the test programs is when main parent process
-  forks a child and then sends a signal to it to start some simulation process. 
-  Depending on the system load and other external factors, it can take a 
+  Semaphore class provides a simpler and easier interface to System V
+  semaphore system calls.
+
+  The very typical situation for the test programs is when the parent process
+  forks a child and then sends a signal to it to start some simulation process.
+  Depending on the system load and other external factors, it can take a
   variable amount of time for the child process to initialize its internal
-  structures and install the appropriate signal handler. Semaphore is used 
+  structures and install the appropriate signal handler. Semaphore is used
   sychronize the parent and child processes, by letting them complete their
   initialization sections.
 
   Implementation Details:
 
-     We create and use a 3-member set for the requested semaphore.
+  We create and use a 3-member set for the requested semaphore.
   The first member, [0], is the actual semaphore value, and the second
   member, [1], is a counter used to know when all processes have finished
-  with the semaphore. The counter is initialized to a large number, 
+  with the semaphore. The counter is initialized to a large number,
   decremented on every Semaphore::create () or Semaphore::open (),
   and incremented on every Semaphore::close ().
+
   This way we can use "adjust" feature provided by System V so that
   any process that exit's without calling Semaphore::close () is accounted
   for. It doesn't help us if the last process does this (as we have
   no way of getting control to remove the semaphore) but it will work if any
   process other than the last does an exit (intentional or unintentional).
 
-     The third member, [2], of the semaphore set is used as a lock 
+  The third member, [2], of the semaphore set is used as a lock
   variable to avoid any race conditions in the Semaphore::create () and
   Semaphore::close () functions.
 
   Note:
 
   This class is a port to C++, inspired by: W. Richard Stevens from his
-  book "dvanced programming in the UNIX Environment" (Prentice Hall, 
-  1992, ISBN 0-201-56317-7).
+  wonderful book, "Advanced programming in the UNIX Environment"
+  (Prentice Hall, 1992, ISBN 0-201-56317-7).
 */
 
 class Semaphore
 {
 public:
-	/// Constructor. 
+	/// Constructor.
 	Semaphore ();
 
 	/// Destructor.
@@ -74,7 +75,7 @@ public:
 
 	/** Create a semaphore with a specified initial value.
 	    If the semaphore already exists, we don't initialize it (of course).
-	    
+
 	    @param  key_ Semaphore's key
 	    @param  initval_ Initiali value (default : 1)
 	    @return The semaphore ID if all OK, else -1
@@ -83,7 +84,7 @@ public:
 
 	/** Open a semaphore that must already exist.
 	    This function should be used, instead of Semaphore::create (),
-	    if the caller knows that the semaphore must already exist. 
+	    if the caller knows that the semaphore must already exist.
 	    For example, a client from a client-server pair would use this,
 	    if its server's responsibility to create the semaphore.
 
@@ -96,9 +97,9 @@ public:
 	    Unlike the Semaphore::remove () function, this function is for a
 	    process to call before it exits, when it is done with the
 	    semaphore. We decrement the counter of processes using
-	    the semaphore, and if this was the last one, 
+	    the semaphore, and if this was the last one,
 	    Semaphore::remove () is called to remove the semaphore.
-	    Calling this method also invalidates object for  subsequent 
+	    Calling this method also invalidates object for  subsequent
 	    operations.
 	*/
 	void close ();
@@ -146,7 +147,7 @@ protected:
 	void init ();
 
 protected:
-	/// Semaphore's key 
+	/// Semaphore's key
 	key_t   m_key;
 
 	/// Semaphore's id
@@ -165,7 +166,7 @@ protected:
 	static sembuf m_op_endcreate [2];
 
 	/** Decrement process counter with undo on exit.
-	    
+
 	*/
 	static sembuf m_op_open      [2];
 
@@ -185,7 +186,7 @@ protected:
 	static sembuf m_op_op        [1];
 };
 
-inline 
+inline
 Semaphore::
 Semaphore ()
 {
@@ -199,7 +200,7 @@ Semaphore::
 ~Semaphore ()
 {
 	trace_with_mask("Semaphore::~Semaphore", SEM);
-	
+
 	if (m_id > 0) {
 		this->close ();
 	}
@@ -211,7 +212,7 @@ init ()
 {
 	m_key = (key_t) -1;
 	m_id  = -1;
-}	
+}
 
 inline void
 Semaphore::
@@ -233,4 +234,4 @@ signal ()
 
 #endif /* !defined(WIN32) */
 
-#endif /* SEMAPHORE_H */  
+#endif /* SEMAPHORE_H */
