@@ -49,6 +49,10 @@ namespace ASSA {
 class SigHandler
 {
 public:
+	/** No-op virtual destructor
+	 */
+	virtual ~SigHandler () { /* no-op */ }
+
 	/** Add new signal handler and new disposition for the signal.
 	    Note that although new_disp_ might keep C-like
 	    handler for the action, new_hand_ will really be
@@ -65,10 +69,10 @@ public:
 	    @return 0 on success, -1 on error
 	*/
 	virtual int install (int            signum_,
-			     EventHandler*  new_hand_,
-			     SigAction*     new_disp_ = 0,
-			     EventHandler** old_hand_ = 0,
-			     SigAction*     old_disp_ = 0);
+						 EventHandler*  new_hand_,
+						 SigAction*     new_disp_ = 0,
+						 EventHandler** old_hand_ = 0,
+						 SigAction*     old_disp_ = 0);
 
 	/** Remove EventHandler associated with signum_. Also,
 	    install new disposition and return an old one (if given).
@@ -83,9 +87,9 @@ public:
 	    @return 0 on success, -1 on error
 	*/
 	virtual int remove (int signum_,
-			    EventHandler* eh_       = 0,
-			    SigAction*    new_disp_ = 0,
-			    SigAction*    old_disp_ = 0);
+						EventHandler* eh_       = 0,
+						SigAction*    new_disp_ = 0,
+						SigAction*    old_disp_ = 0);
 
 	/** Here is the heart of SigHandler class. This callback function
 	    is really registered with OS to catch all of the signals 
