@@ -11,7 +11,7 @@
 //------------------------------------------------------------------------------
 //
 //  This class is a direct derivative from my Unix Network Programming
-//  class work on generalizing OO network interfaces.
+//  class work on generalizing object-oriented network interfaces.
 //
 //------------------------------------------------------------------------------
 //  Created: 03/22/1999
@@ -22,16 +22,17 @@
 
 #include <sys/stat.h>
 #include <sys/time.h>
-#include <limits.h>		// for INT_MAX
-#include <stdio.h>		// for EOF
+#include <limits.h>				// for INT_MAX
+#include <stdio.h>				// for EOF
 #include <sys/types.h>
 #include <unistd.h>
-#include <fcntl.h>		// for fcntl(2)
+#include <fcntl.h>				// for fcntl(2)
 
 #ifdef linux
-#  include <sys/ioctl.h>	// ioctl(2)
+#  include <sys/ioctl.h>		// ioctl(2)
 #endif
-#ifdef sun			// ioctl(2)
+
+#ifdef sun						// ioctl(2)
 #  include <unistd.h>
 #  include <stropts.h>
 #  include <sys/filio.h>
@@ -94,30 +95,35 @@ public:
 	/** @enum opt_t
 	 *  Socket options.
 	 */
-	enum opt_t { 
+	enum opt_t 
+	{ 
 		reuseaddr,   /**< Allow local address reuse. */
+
 		rcvlowat,    /**< The receiver low-water mark is the 
 						amount of data that must be in the socket receive 
 						buffer for select(3) to return "readable". It defaults
 						to 1 for a TCP and UDP socket (NOTE: Posix.1g does not 
 						require support for this option). */
+
 		sndlowat,    /**< The send low-water mark si the amount
 						of available space that must exist in the socket send 
 						buffer for select to return "writable". This low-water 
 						mark normally defaults to 2048 for TCP socket. UDP 
 						socket is always writable (NOTE: Posix.1g does not 
 						require support for this option) */
-		blocking,    /**< Default behaviour - all read/write operations
-						on socket are blocking. 
-						For input operations, if there is no data 
-						available in the socket receiver buffer, we are put 
-						to sleep until some data arrives. 
 
-						For output operations, if there is no room in 
-						the socket send buffer for a blocking socket, the 
-						process is put to sleep until there is room.
-					 */
-		nonblocking  /**< Set Socket to a non-blocking mode.
+		nonblocking  /**< Set Socket to a non-blocking mode (O_RDWR|O_NONBLOCK).
+
+					    The default setup for a socket is BLOCKING (O_RDWR),
+						Blocking implies being suspended while waiting
+						for data to arrive on read. On write, it means
+						that there is no room to send all data out and
+						the process is being suspended until more room
+						in the output buffer becomes available.
+
+						Use nonblocking option to set the socket to
+						non-blocking mode.
+
 						For input operations, if an operation cannot be
 						satisfied (at least 1 byte of data for a TCP socket 
 						or a complete datagram for a UDP socket), return is 
@@ -128,8 +134,11 @@ public:
 						immediately with an error of EWOULDBLOCK. If, 
 						however, there is some room in the socket send buffer, 
 						the return value will be the number of bytes that the 
-						kernel was able to copy into the buffer.
-						(This is called a short count.
+						kernel was able to copy into the buffer
+						(This is called a short count).
+
+						NOTE: To go back to blocking mode, clear nonblocking
+						with turnOptionOff().
 					  */
 	};
 
@@ -163,7 +172,7 @@ public:
 	    @param buf_  packet to send
 	    @param size_ size of the packet
 	 */
-	virtual int write (const char* buf_, const unsigned int size_); 
+	virtual int write (const char* buf_, const u_int size_); 
 
 	/** Return number of bytes available in socket receive buffer.
 	 */
@@ -173,7 +182,7 @@ public:
 	    @param buf_ buffer to save received packet to
 	    @param size_ size of the packet
 	 */
-	virtual int read (char* buf_, const unsigned int size_);
+	virtual int read (char* buf_, const u_int size_);
 
 	/** Extracts bytes and discards them. With no arguments,
 	    read and discard until eof is encountered.
@@ -215,7 +224,7 @@ public:
 	int ignore (int n_ = INT_MAX, int delim_ = EOF);
 
 	/// Get file descriptor
-	virtual const int getHandler() const = 0;
+	virtual handler_t getHandler() const = 0;
 
 	/// Get socket domain
 	virtual const int getDomain() const = 0;
@@ -317,9 +326,9 @@ public:
 	    @return true if failbit or badbit is set, false otherwise
 	 */
 	bool fail () const 
-		{ 
-			return m_state & (Socket::failbit | Socket::badbit);
-		}
+	{ 
+		return m_state & (Socket::failbit | Socket::badbit);
+	}
 
 	/** Socket fd == -1 or read/write error occured or some loss 
 	    of integrity on assosiated stream buffer.
@@ -427,11 +436,33 @@ public:
 	}
 
 	/** Determine the endianess of the platform we are on.
-		@return true if it is a little-endian host; 
-		        false if a big-endian host.
+	 *
+	 *  @return true if it is a little-endian host; 
+	 *	        false if a big-endian host.
 	*/
 	static bool is_little_endian ();
 
+	/** Close socket endpoint in a portable way.
+	 *  Socket is also set to an invalid value.
+	 */
+	static void close_handler (handler_t& socket_)
+	{
+#if defined (WIN32)
+		closesocket (socket_);
+#else
+		::close (socket_);
+#endif
+		disable_handler (socket_);
+	}
+
+	/** Decipher flags packed into mask_ used in fcntl() call.
+	 */
+	static string decode_fcntl_flags (long mask_);
+
+/*------------------------------------------------------------------
+ * Protected Members
+ *------------------------------------------------------------------
+ */
 protected:
 	/** Gateway method of setting socket options.
 	    @return 0 on success, -1 on error (setsockopt(2) failed)
@@ -441,20 +472,26 @@ protected:
 	/** Gateway method for setting file descriptor options.
 	    @return 0 on success, -1 on error (fcntl(2) failed)
 	*/
-	int set_fd_options (int flags_);
+	int set_fd_options (long flags_);
 
 	/** Gateway method for clearing file descriptor options.
 	    @return 0 on success, -1 on error (fcntl(2) failed)
 	*/
-	int clear_fd_options (int flags_);
+	int clear_fd_options (long flags_);
 
 protected:
-	/// File descriptor
-	int m_fd;
+	/** File descriptor
+	 */
+	handler_t m_fd;				// u_int, INVALID_SOCKET=(SOCKET)(~0)
 
 	/// Socket domain type
 	int m_type;
 
+#if defined (WIN32)
+	bool m_nonblocking;		// We cannot retrieve the status of the 
+                            // socket. So, we remember what it was instead.
+#endif
+
 	/// Control state of the socket
 	IOState m_state;
 
@@ -479,7 +516,13 @@ private:
 
 inline
 Socket::Socket() 
-	: m_fd(-1), m_type(0), m_state(Socket::badbit)
+	: 
+	m_fd (BAD_HANDLER),
+	m_type(0),
+#if defined (WIN32)
+	m_nonblocking (false),
+#endif
+	m_state(Socket::badbit)
 {
 	trace_with_mask("Socket::Socket",SOCKTRACE);
 }
@@ -498,14 +541,14 @@ Socket::connect (const Address& /* address_ */)
 }
 
 inline int 
-Socket::write(const char* /*buf_*/, const unsigned int /*size_*/) 
+Socket::write(const char* /*buf_*/, const u_int /*size_*/) 
 { 
 	trace_with_mask("Socket::write",SOCKTRACE); 
 	return -1; 
 }
 
 inline int 
-Socket::read(char* /*buf_*/, const unsigned int /*size_*/)  
+Socket::read(char* /*buf_*/, const u_int /*size_*/)  
 { 
 	trace_with_mask("Socket::read()",SOCKTRACE);
 	return -1; 
@@ -527,7 +570,7 @@ Socket::operator!() const
 inline void 
 Socket::clear(iostate state_)
 { 
-	m_state = m_fd >=0 ? state_ : state_ | Socket::badbit; 
+	m_state = is_valid_handler (m_fd) ? state_ : state_ | Socket::badbit; 
 }
 
 inline void 
