@@ -90,10 +90,20 @@ public:
 class Streambuf : public io_ptrs
 {
 public:
+
+//  Old comment:
+//
+//  "Maximum frame size that can be transmitted unfragmented by TCP
+//   with MTU 1500 (1500-20-60). TCP frame can have options
+//   (up to 60 bytes) which, if ignored, might cause fragmentation.
+//   Also, the length of the IP packet must be evenly divisible by 8."
+//
+//  On 100Mb networks, the reasonable buffer size seems to be 64K.
+
     /** Size of the internal input/output buffer. You can use this
 	 *  constant to do application code read/writes to the socket.
 	 */
-	static const int Streambuf::MAXTCPFRAMESZ = 65536;	// 64K
+	static const int MAXTCPFRAMESZ = 65536;	// 64K
 
 	virtual ~Streambuf ();
 
