@@ -1,6 +1,6 @@
 // -*- c++ -*-
 //------------------------------------------------------------------------------
-// $Id: bufio_testc.cpp,v 1.8 2005/10/08 02:42:01 vlg Exp $
+// $Id: bufio_testc.cpp,v 1.9 2006/07/20 02:30:55 vlg Exp $
 //------------------------------------------------------------------------------
 //  This program is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU General Public License
@@ -78,6 +78,8 @@ const char title[] =
 "                                                                           \n";
 //------------------------------------------------------------------------------
 
+#if !defined (WIN32)
+
 #include <string> 
 using std::string;
 
@@ -429,7 +431,7 @@ SvrProxy::handle_timeout (TimerId /* tid_ */)
     else tn = "UNKNOWN STATE";
 
     msg = "Timed out waiting on " + tn + " response.";
-    EL((ERROR,"%s\n", msg.c_str()));
+    EL((ASSA::ASSAERR,"%s\n", msg.c_str()));
     cout << msg << "\n";
 
     close ();
@@ -593,8 +595,13 @@ SvrProxy::run_test4 ()
 
 #define CLIENT  Client::get_instance ()
 
+#endif   /* !defined WIN32 */
+
 int main (int argc, char* argv[])
 {
+
+#if !defined (WIN32)
+
     string release ("1.1");
     int revision = 0;
 
@@ -605,4 +612,8 @@ int main (int argc, char* argv[])
 
     CLIENT->init_service ();
     CLIENT->process_events ();
+
+#endif   /* !defined WIN32 */
+
+	return 0;
 }
