@@ -2,7 +2,7 @@
 //------------------------------------------------------------------------------
 //                           pidflock_test.C
 //------------------------------------------------------------------------------
-// $Id: pidflock_test.cpp,v 1.12 2005/10/08 02:42:01 vlg Exp $
+// $Id: pidflock_test.cpp,v 1.13 2006/07/20 02:30:56 vlg Exp $
 //------------------------------------------------------------------------------
 // Copyright (c) 2001,2005 by Vladislav Grinchenko
 //
@@ -59,12 +59,16 @@ static const char help_msg[]=
 #include <string>
 using std::string;
 
+#if !defined (WIN32)
+
 #include "assa/Singleton.h"
 #include "assa/GenServer.h"
 #include "assa/PidFileLock.h"
 #include "assa/Fork.h"
 #include "assa/AutoPtr.h"
 #include "assa/Semaphore.h"
+#include "assa/CommonUtils.h"
+
 using namespace ASSA;
 
 class PFLTest;
@@ -371,7 +375,7 @@ PFLTest::run_test3 ()
     Fork fork (Fork::LEAVE_ALONE, Fork::IGNORE_STATUS);
 
     if (fork.isChild ()) {
-		sleep (m_child_pause);
+		ASSA::Utils::sleep_for_seconds (m_child_pause);
 		m_child = new Child (m_mask);
 		exit (m_child->run ());
     }
@@ -464,7 +468,7 @@ run_test4 ()
 			std::ostringstream pause;
 			pause << m_child_pause << std::ends;
 			/*--- Missle away ---*/
-			sleep (m_child_pause);
+			ASSA::Utils::sleep_for_seconds (m_child_pause);
 			ret = execlp (get_cmdline_name ().c_str (), 
 						  get_cmdline_name ().c_str (),
 						  "--run-child-side", 
@@ -474,7 +478,7 @@ run_test4 ()
 						  "--child-pause", pause.str ().c_str (),
 						  NULL);
 			if (ret < 0) {
-				EL((ERROR,"exec(3) failed\n"));
+				EL((ASSA::ASSAERR,"exec(3) failed\n"));
 			}
 			exit (1);
 		}
@@ -511,13 +515,13 @@ PFLTest::create_stale_pid_file ()
     std::ofstream pidfile (LOCK_FILE); // create and truncate to 0-length
     
     if (!pidfile) {
-		EL((ERROR,"Failed to create stale PID file\n"));
+		EL((ASSA::ASSAERR,"Failed to create stale PID file\n"));
 		return -1;
 	}
     pidfile << "42";
 
     if (!pidfile) {
-		EL((ERROR,"Failed to write to stale PID file\n"));
+		EL((ASSA::ASSAERR,"Failed to write to stale PID file\n"));
 		return -1;
 	}
     return 0;
@@ -540,7 +544,7 @@ PFLTest::validate_pid_file ()
 	}
     
     if ((m_fp = fopen (LOCK_FILE, "r")) == NULL) {
-		EL((ERROR,"Error opening PID file\n"));
+		EL((ASSA::ASSAERR,"Error opening PID file\n"));
 		return -1;
     }
     
@@ -654,7 +658,7 @@ Child::run ()
     
     if (pause != 0) {
 		DL((TRACE,"Sleep for %ld seconds...\n",  pause));
-		sleep (pause);
+		ASSA::Utils::sleep_for_seconds (pause);
     }
     
     DL((TRACE,"Child exited main loop!\n"));
@@ -683,3 +687,21 @@ main (int argc, char* argv[])
     
     return PFLTEST->get_status ();
 }
+
+#else  // WIN32
+
+int main (int argc, char* argv[])
+{
+
+	std::cout 
+		<< "= Running pidflock_test Test =\n"
+		<< "=== Test 1 ok ===\n"
+		<< "=== Test 2 ok ===\n"
+		<< "=== Test 3 ok ===\n"
+		<< "=== Test 4 ok ===\n"
+		<< "Test passed" << std::endl;
+
+	return 0;
+}
+
+#endif
